#<profile4xi profile = "02" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "iteratorproxy4xi.py">
#<abstract4xi abstract = "provides class IteratorProxy4Xi"/>
#<refer4xi reference = "managers.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------


# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'IteratorProxy4Xi' ] 
#"
#/>

#/>
# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass

                
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                           
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.managers import IteratorProxy
except:
    print("iteratorproxy4xi.py *** failed in from multiprocessing.managers import IteratorProxy ***")
#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from baseproxy4xi import BaseProxy4Xi

from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi

from time4xi import time4xi
  
#"
#/>


# =================================================================================================
#<class4xi class = "IteratorProxy4Xi" base = "BaseProxy4Xi" child = "None" synopsis = "Provides iterator proxy services" usage = "
#     managers.py
#         SyncManager.register('Iterator', proxytype=IteratorProxy, create_method=False)
#
#     syncmanager4xi.py
#         SyncManager4Xi.register('Iterator', proxytype=IteratorProxy4Xi, create_method=False)
#
#     imapiterator4xi.py:
#         IteratorProxy4Xi.__next__ = next"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class IteratorProxy4Xi(BaseProxy4Xi):
    '''
    IteratorProxy4Xi class: in managers.py SyncManager.register('Iterator', proxytype=IteratorProxy, create_method=False) 
    '''

    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi exposure = "
    _exposed_ = ('send', 'throw', 'close', 'sense', 'reason', 'ace')   
    #"
    #/>
                                     
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "iter-of-IteratorProxy4Xi" usage = "returns with (self)">                           
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def __iter__(self):
        '''
        IteratorProxy4Xi method __iter__: returns with (self) 
        '''
        class2print = "IteratorProxy4Xi"
        method2print = "__init__"
        
        message2print = "{started" + "; iter-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                         
        message2print = "{returning" + "; iteratorproxy2xi-returning-by-iter-of-IteratorProxy4Xi: " + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    

        return self
        
    #</methodize4xi>
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "next-of-IteratorProxy4Xi" usage = "returns with (self, *args)">                        
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def __next__(self, *args):
        '''
        IteratorProxy4Xi method __next__:  returns with (self, *args)
        '''      
        class2print = "IteratorProxy4Xi"
        method2print = "__next__"
        
        message2print = "{started" + "; next-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
   
        
        message2print = "{passing" + "; next-passing-to-callmethod-by-send-of-IteratorProxy4Xi: " + str('__next__') + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

                          
        message2print = "{returning" + "; callmethod-function-returning-by-next-of-IteratorProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        return self._callmethod('__next__', args)
        
    #</methodize4xi>
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "send-of-IteratorProxy4Xi" usage = "returns with (self, *args)">                          
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def send(self, *args):
        '''
        IteratorProxy4Xi method send:  returns with (self, *args) 
        '''
        class2print = "IteratorProxy4Xi"
        method2print = "send"
        
        message2print = "{started" + "; send-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        

        
        message2print = "{returning" + "; callmethod-function-returning-by-send-of-IteratorProxy4XiZ: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                
        message2print = "{passing" + "; send-passing-to-callmethod-by-send-of-IteratorProxy4XiZ: " + str('send') + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
        message2print = "{passing" + "; args-passing-to-callmethod-by-send-of-IteratorProxy4XiZ: " + str(args) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                   
                
        return self._callmethod('send', args)
        
    #</methodize4xi>
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "throw-of-IteratorProxy4Xi" usage = "returns with (self, *args)">                            
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def throw(self, *args):
        '''
        IteratorProxy4Xi method throw: returns with (self, *args) 
        '''
        class2print = "IteratorProxy4Xi"
        method2print = "throw"
        
        message2print = "{started" + "; throw-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
       
        message2print = "{returning" + "; callmethod-function-returning-by-throw-of-IteratorProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                        
        message2print = "{passing" + "; throw-passing-to-callmethod-by-throw-of-IteratorProxy4Xi: " + str('throw') + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
        message2print = "{passing" + "; args-passing-to-callmethod-by-throw-of-IteratorProxy4Xi: " + str(args) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                 
        return self._callmethod('throw', args)

    #</methodize4xi>
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "close-of-IteratorProxy4Xi" usage = "returns with (self, *args)">                          
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def close(self, *args):
        '''
        IteratorProxy4Xi method close: returns with (self, *args) 
        '''
        class2print = "IteratorProxy4Xi"
        method2print = "close"
        
        message2print = "{started" + "; close-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        message2print = "{returning" + "; callmethod-function-returning-by-close-of-IteratorProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                
        message2print = "{passing" + "; close-passing-to-callmethod-by-close-of-IteratorProxy4Xi: " + str('close') + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
        message2print = "{passing" + "; args-passing-to-callmethod-by-close-of-IteratorProxy4Xi: " + str(args) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                         

        return self._callmethod('close', args)
        
    #</methodize4xi>
                                           
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-IteratorProxy4Xi" usage = "senses IteratorProxy4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses IteratorProxy4Xi class objects
        '''
         
        
        class2print = 'IteratorProxy4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; IteratorProxy4Xi-sensing-by-sense-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                 
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-IteratorProxy4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb2xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------         
    
        
        
        message2print = "{sensed" + "; IteratorProxy4Xi-sensed-by-sense-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-IteratorProxy4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                  
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-IteratorProxy4Xi" usage = "reasons IteratorProxy4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons IteratorProxy4Xi class objects
        '''
           
        
        class2print = 'IteratorProxy4Xi'
        method2print = 'reason'
        
        message2print = "{started" + "; reason-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
    
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; IteratorProxy4Xi-reasoning-by-reason-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-IteratorProxy4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        message2print = "{reasoned" + "; IteratorProxy4Xi-reasoned-by-reason-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-IteratorProxy4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                        
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-IteratorProxy4Xi" usage = "aces IteratorProxy4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces IteratorProxy4Xi class objects 
        '''
           
        
        
        class2print = 'IteratorProxy4Xi'
        method2print = 'ace'
        
        message2print = "{started" + "; ace-of-IteratorProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; IteratorProxy4Xi-acing-by-ace-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-IteratorProxy4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; IteratorProxy4Xi-aced-by-ace-of-IteratorProxy4Xi: " + str(IteratorProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-IteratorProxy4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------               
    #</methodize4xi>
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
     

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of iteratorproxy4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>



